mdl-R33: an extensive library for the exploration, visualization, and analysis of eyetracking data.
----------------------------------------------
<div class="row">
	<a href="https://liberalarts.utexas.edu/imhr/">
		<img src="./docs/source/_static/img/imhr.png" height="auto" width="100%" max-width="400px">
	</a>
<div>

--------------------------------------
[![PyPI Version](https://img.shields.io/pypi/v/mdl-R33.svg)](https://pypi.org/project/mdl-R33/)
[![License](https://img.shields.io/pypi/l/mdl-R33.svg)](https://github.com/mwaskom/risoms/blob/master/LICENSE)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1313201.svg)](https://doi.org/10.1016/j.cct.2018.10.014)
[![Build Status](https://travis-ci.org/risoms/mdl-R33.svg?branch=master)](https://travis-ci.org/risoms/mdl-R33)
[![Code Coverage](https://codecov.io/gh/risoms/seaborn/branch/master/graph/badge.svg)](https://codecov.io/gh/risoms/mdl-R33)

This study is funded by NIMH grant MH109600. 
Hsu, K. J., Caffey, K., Pisner, D., Shumake, J., Risom, S., Ray, K. L., . . . Beevers, C. G. (2018). 
	Attentional bias modification treatment for depression: Study protocol for a randomized controlled trial. 
	Contemporary Clinical Trials, 75, 59-66. doi:https://doi.org/10.1016/j.cct.2018.10.014

This package was created at the [Institute for Mental Health Research](http://mdl.psy.utexas.edu/), at [the University of Texas at Austin](http://www.utexas.edu/) by [Semeon Risom](https://semeon.io).


Documentation
-------------
Online documentation is available at [mdl-R33](https://risoms.github.io/mdl-R33/output/analysis/html/docs/py-modindex.html).

The docs include a [tutorial](https://risoms.github.io/mdl-R33/docs/build/examples/download.html), [API reference](https://risoms.github.io/mdl-R33/docs/build/api/imhr.R33.html), and other useful information.


Dependencies
------------

mdl-R33 supports Python 3.6+.

Installation requires [numpy](http://www.numpy.org/), [scipy](https://www.scipy.org/), [rpy2](https://rpy2.readthedocs.io/), [pandas](https://pandas.pydata.org/), and [matplotlib](https://matplotlib.org/). Some functions will optionally use [statsmodels](https://www.statsmodels.org/) if it is installed.


Installation
------------

The latest stable release (and older versions) can be installed from Github:

    pip install git+https://github.com/risoms/mdl-R33.git